@@ -15,5 +15,7 @@ RCT_EXPORT_VIEW_PROPERTY(width, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(height, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(themeColor, NSString)
 RCT_EXPORT_VIEW_PROPERTY(onChange, RCTBubblingEventBlock)
+RCT_EXPORT_VIEW_PROPERTY(minLength, NSNumber)
+RCT_EXPORT_VIEW_PROPERTY(maxLength, NSNumber)
 
 @end
